@@ -159,5 +159,6 @@ def construct_signing_middleware(
                 [raw_tx])
 
         return middleware
-
-    return sign_and_send_raw_middleware
+    smw = sign_and_send_raw_middleware
+    smw.address = account.address
+    return smw
